@@ -4,7 +4,7 @@ use geo_types::LineString;
 use serde::{Deserialize, Serialize};
 
 use h3ron::to_geo::{ToLineString, ToMultiLineString};
-use h3ron::{H3Cell, H3Edge, Index};
+use h3ron::{ExactLength, H3Cell, H3Edge, Index};
 
 use crate::error::Error;
 
@@ -76,7 +76,7 @@ impl<W> Path<W> {
         }
     }
 
-    pub fn cost(&self) -> &W {
+    pub const fn cost(&self) -> &W {
         match self {
             Self::OriginIsDestination(_, c) => c,
             Self::EdgeSequence(_, c) => c,
@@ -89,6 +89,34 @@ impl<W> Path<W> {
             Self::OriginIsDestination(_, _) => &[],
         }
     }
+
+    /// return a vec of all [`H3Cells`] the path passes through.
+    pub fn cells(&self) -> Vec<H3Cell> {
+        match self {
+            Path::OriginIsDestination(cell, _) => vec![*cell],
+            Path::EdgeSequence(edges, _) => {
+                let mut cells = Vec::with_capacity(edges.len() + 1);
+                for edge in edges.iter() {
+                    cells.push(edge.origin_index_unchecked());
+                    cells.push(edge.destination_index_unchecked());
+                }
+                cells.dedup();
+                cells.shrink_to_fit();
+                cells
+            }
+        }
+    }
+
+    /// calculate the length of the path in meters using the exact length of the
+    /// contained edges
+    pub fn length_m(&self) -> f64 {
+        match self {
+            Path::OriginIsDestination(_, _) => 0.0,
+            Path::EdgeSequence(edges, _) => {
+                edges.iter().map(|edge| edge.exact_length_m()).sum::<f64>()
+            }
+        }
+    }
 }
 
 /// order by cost, origin index and destination_index.
