@@ -4,7 +4,7 @@ use serde::{Deserialize, Serialize};
 
 use h3ron::H3Cell;
 
-use crate::graph::GetNodeType;
+use crate::graph::GetCellNode;
 
 #[derive(PartialEq, Debug, Copy, Clone, Serialize, Deserialize)]
 pub enum NodeType {
@@ -14,7 +14,7 @@ pub enum NodeType {
 }
 
 impl NodeType {
-    pub fn is_origin(&self) -> bool {
+    pub const fn is_origin(&self) -> bool {
         match self {
             NodeType::Origin => true,
             NodeType::Destination => false,
@@ -22,7 +22,7 @@ impl NodeType {
         }
     }
 
-    pub fn is_destination(&self) -> bool {
+    pub const fn is_destination(&self) -> bool {
         match self {
             NodeType::Origin => false,
             NodeType::Destination => true,
@@ -31,10 +31,10 @@ impl NodeType {
     }
 }
 
-impl Add<NodeType> for NodeType {
-    type Output = NodeType;
+impl Add<Self> for NodeType {
+    type Output = Self;
 
-    fn add(self, rhs: NodeType) -> Self::Output {
+    fn add(self, rhs: Self) -> Self::Output {
         if rhs == self {
             self
         } else {
@@ -43,8 +43,8 @@ impl Add<NodeType> for NodeType {
     }
 }
 
-impl AddAssign<NodeType> for NodeType {
-    fn add_assign(&mut self, rhs: NodeType) {
+impl AddAssign<Self> for NodeType {
+    fn add_assign(&mut self, rhs: Self) {
         if self != &rhs {
             *self = Self::OriginAndDestination
         }
@@ -64,7 +64,7 @@ pub enum GapBridgedCellNode {
 }
 
 impl GapBridgedCellNode {
-    pub fn cell(&self) -> H3Cell {
+    pub const fn cell(&self) -> H3Cell {
         match self {
             Self::DirectConnection(cell) => *cell,
             Self::WithGap(cell, _) => *cell,
@@ -72,7 +72,7 @@ impl GapBridgedCellNode {
         }
     }
 
-    pub fn corresponding_cell_in_graph(&self) -> Option<H3Cell> {
+    pub const fn corresponding_cell_in_graph(&self) -> Option<H3Cell> {
         match self {
             Self::DirectConnection(cell) => Some(*cell),
             Self::WithGap(_, cell) => Some(*cell),
@@ -104,7 +104,7 @@ pub trait GetGapBridgedCellNodes {
 
 impl<G> GetGapBridgedCellNodes for G
 where
-    G: GetNodeType + Sync,
+    G: GetCellNode + Sync,
 {
     fn gap_bridged_corresponding_node_filtered<F>(
         &self,
@@ -116,7 +116,7 @@ where
         F: Fn(&H3Cell, &NodeType) -> bool + Send + Sync + Copy,
     {
         if self
-            .get_node_type(cell)
+            .get_cell_node(cell)
             .map(|node_type| nodetype_filter_fn(cell, node_type))
             .unwrap_or(false)
         {
@@ -131,7 +131,7 @@ where
             let mut selected_neighbor: Option<H3Cell> = None;
             for neighbor in neighbors {
                 if self
-                    .get_node_type(&neighbor.1)
+                    .get_cell_node(&neighbor.1)
                     .map(|node_type| nodetype_filter_fn(&neighbor.1, node_type))
                     .unwrap_or(false)
                 {
